@@ -28,6 +28,7 @@ import logging
 from contextlib import closing
 import socket
 
+
 class TARGETError(Exception):
     """
     Exception for target validity
@@ -59,6 +60,8 @@ class Target:
         elif self.is_ssh():
             self.login, self.path = target.split(':')
             self.domain = self.login.split('@')[1]
+        if not os.path.exists(self.path):
+            raise TARGETError("Target %s unreachable" % self.target)
 
     def is_dir(self):
         """
@@ -87,7 +90,7 @@ class Target:
         Check if the target is available
         For SSH host, it means it's reachable
 
-        :returns: bool -- True is available
+        :raises: TARGETError -- if not available
         """
         if self.ttype == 'SSH':
             sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
@@ -95,19 +98,15 @@ class Target:
                 sock.connect((self.domain, 22))
             except socket.error:
                 raise TARGETError("Target %s unreachable" % self.target)
-            else:
-                return True
         elif self.ttype == 'DIR':
-            pass #TODO
-
+            if not os.path.exists(self.path):
+                raise TARGETError("Target %s unreachable" % self.target)
 
     def _detect_target_type(self):
         """
         Return the target type
         SSH if matches name@domaine.tld:dir
         DIR if it's a directory
-
-        :raises TARGETError: weird target type
         """
         #if re.match('[a-zA-Z0-9+_\-\.]+@[0-9a-zA-Z][.-0-9a-zA-Z]*.[a-zA-Z]+\:.*', self.target):
         if re.match('[a-zA-Z0-9+_\-\.]+@[a-zA-Z0-9+_\-\.]+\:.*', self.target):
@@ -115,13 +114,8 @@ class Target:
             self.logger.debug("The target %s looks like SSH", self.target)
             return 'SSH'
         else:
-            if not os.path.exists(self.target):
-                self.logger.warning("The target %s does not exist", self.target)
-                raise TARGETError("Target %s does not exist" % self.target)
-            else:
-                self.logger.debug("The target %s looks like DIR", self.target)
-                return 'DIR'
-
+            self.logger.debug("The target %s looks like DIR", self.target)
+            return 'DIR'
 
 
 class Job:
@@ -144,6 +138,8 @@ class Job:
     :type duration: int
     :param keep: How many snapshots are (at least) kept
     :type keep: int
+    :param force: overide the timebase check, no min. duration.
+    :type filter: bool
     :param filter: Rsync filters
     :type filter: list
 
@@ -154,7 +150,7 @@ class Job:
         or a ssh login joined to the path by a : character.
     """
 
-    def __init__(self, log_dir, name, source, destination, period, snapshot, duration, keep, filter):
+    def __init__(self, log_dir, name, source, destination, period, snapshot, duration, keep, force, filter):
 
         self.name = name
         self.source = Target(source)
@@ -165,6 +161,7 @@ class Job:
         self.keep = keep
         self.filter = filter
 
+        self.force = force
         self.now = datetime.datetime.now()
         self.current_date = self.now.strftime("%Y-%m-%d_%Hh%Mm%Ss")
 
@@ -183,8 +180,6 @@ class Job:
         self.previous_backup_path = None
         self.current_backup_path = None
 
-
-
 #    def _check_disk_usage(self):
 #        """
 #        Check the disk usage
@@ -208,7 +203,6 @@ class Job:
         with closing(shelve.open(os.path.join(self.backup_log_dir, 'time.db'))) as timebase:
             timebase[self.name] = datetime.datetime.now()
 
-
     def _check_need_backup(self):
         """
         Return True if backup needed
@@ -288,7 +282,6 @@ class Job:
                 process = subprocess.Popen(command, bufsize=4096, stdout=subprocess.PIPE)
                 stdout, stderr = process.communicate()
 
-
     def _get_last_backup(self):
         """
         Get the last backup path
@@ -311,7 +304,6 @@ class Job:
             stdout, stderr = process.communicate()
             self.logger.debug('SSH mkdir result: ' + stdout.decode())
 
-
             command = ['ssh', '-t', self.destination.login, 'ls', '-1', path]
             self.logger.debug('SSH ls command: ' + str(command))
             process = subprocess.Popen(command, bufsize=4096, stdout=subprocess.PIPE)
@@ -321,7 +313,8 @@ class Job:
             filenames = [x.strip('\r') for x in filenames if x!='']
 
         last = utils.get_last_file(filenames)
-        last = os.path.join(path, last)
+        if last is not None:
+            last = os.path.join(path, last)
         self.logger.debug('_get_last_backup returns: %s', last)
         return last
 
@@ -333,7 +326,7 @@ class Job:
         self.destination.check_availability()
         if self.destination.is_dir():
             if self.snapshot:
-                os.makedirs(self.current_backup_path) # This one does not exist!
+                os.makedirs(self.current_backup_path)  # This one does not exist!
             else:
                 if self.previous_backup_path is None:
                     os.makedirs(self.current_backup_path, exist_ok=True)
@@ -348,7 +341,6 @@ class Job:
             stdout, stderr = process.communicate()
             self.logger.debug('SSH mkdir result: ' + stdout.decode())
 
-
     def _prepare_rsync_command(self):
         """
         Compose the rsync command
@@ -377,7 +369,6 @@ class Job:
             path = os.path.basename(self.previous_backup_path)
             command.append('--link-dest=../' + path)
 
-
         # Add source and destination
         command.append(self.source.target)
         if self.destination.is_ssh():
@@ -441,7 +432,7 @@ class Job:
             self.logger.debug("Previous backup path: %s", self.previous_backup_path)
             self.logger.debug("Current backup path: %s", self.current_backup_path)
 
-            if self._check_need_backup():
+            if self._check_need_backup() or self.force:
                 self.job_logger.info('='*20 + str(self.now) + '='*20)
                 self.logger.debug('Start Backup: %s', self.name)
                 print(self.name)
@@ -460,7 +451,7 @@ class Job:
                 self._set_lastbackup_time()
 
                 # Remove old snapshots
-                self._delete_old_files(days=10, keep=10) # TODO adjustable in API
+                self._delete_old_files(days=self.duration, keep=self.keep)
 
                 # Create symlink
                 last = os.path.join(self.destination.path, self.name, 'last')
